@@ -1,11 +1,11 @@
-__version__ = "0.1.3"
+__version__ = "0.1.4"
 __author__ = 'Hanrui Wang'
 
 from .macro import *
 from .devices import *
 from .module import *
 from .operators import *
-from .measure import *
+from .measurement import *
 from .functional import *
 from .graph import *
 from .layers import *
